<?php
/**
 * Constants for the G2 Glossary module
 * These definitions were previously in g2.module itself.
 *
 * @copyright Copyright (C) 2005-2009 Frederic G. MARAND for Ouest Systèmes Informatiques (OSInet)
 * @since DRUPAL_4_7
 * @name $Name$
 *
 * @license Licensed under the CeCILL, version 2
 *
 * License note: G2 is distributed by OSInet to its customers under the
 * CeCILL 2.0 license. OSInet support services only apply to the module
 * when distributed by OSInet, not by any third-party further down the
 * distribution chain.
 *
 * If you obtained G2 from drupal.org, that site received it under the
 * GPLv2 license and can therefore distribute it under the GPLv2, and
 * so can you and just anyone down the chain as long as the GPLv2 terms
 * are abided by, the module distributor in that case being the
 * drupal.org organization or the downstream distributor, not OSInet.
 */

/**
 * Constants missing from node.module versions (still missing from node.module 1.582, see http://drupal.org/node/43355)
 */
if (!defined('NODE_PUBLISHED'))
  {
  define('NODE_NOT_PUBLISHED', 0);
  define('NODE_PUBLISHED', 1)  ;
  define('NODE_NOT_IN_MODERATION', 0);  // moderate
  define('NODE_IN_MODERATION', 1);
  define('NODE_NOT_PROMOTED', 0);       // promote
  define('NODE_PROMOTED', 1);
  define('NODE_NOT_STICKY', 0);         // sticky
  define('NODE_STICKY', 1);
  }

class G2
  {
  /**
   * G2 various constants
   */
  const NODE_TYPE             = 'g2_entry'; // change PATH_NODE_ADD accordingly if renaming this
  const PERM_VIEW             = 'view g2 entries';
  const PERM_ADMIN            = 'administer g2 entries';
  const VERSION               = '$Id$';
  const BRANCH                = '$Name$';

  /**
   * G2 menu information
   */
  const PATH_AUTOCOMPLETE     = 'g2/autocomplete';
  const PATH_ENTRIES          = 'g2/entries';
  const PATH_INITIAL          = 'g2/initial';
  const PATH_SETTINGS         = 'admin/settings/g2';
  const PATH_NODE_ADD         = 'node/add/g2-entry'; // depends on NODE_TYPE, "_" replaced by "-"
  const PATH_WOTD_FEED        = 'g2/wotd/feed';

  const TITLE_AUTOCOMPLETE    = 'Entry autocomplete';
  const TITLE_ENTRIES         = 'G2 entries by name';
  const TITLE_INITIAL         = 'Entries starting by initial !initial';
  const TITLE_MAIN            = 'G2 glossary main page';
  const TITLE_SETTINGS        = 'G2 Glossary';
  const TITLE_WOTD_FEED       = 'G2 word of the day RSS feed';

  /**
   * Block deltas
   */
  const DELTA_ALPHABAR        = 'alphabar';
  const DELTA_RANDOM          = 'random';
  const DELTA_TOP             = 'top';
  const DELTA_WOTD            = 'wotd';
  const DELTA_LATEST          = 'latest';

  /**
   * G2 settings and block configuration, persisted in {variable}
   */
  const VAR_ALPHABAR_STRING   = 'g2_alphabar_string';   // Alphabar block: list of the one-symbol initials being displayed. Stored unencoded.
  const VAR_ALPHABAR_ROW_LEN  = 'g2_alphabar_rowlen';   // Alphabar block: row length of the themed alphabar
  const VAR_ALPHABAR_TITLE    = 'g2_alphabar_title';    // Alphabar block: title
  const VAR_GOTO_SINGLE       = 'g2_goto_single';       // Automatically go to the match on an "entries" page if only one exists
  const VAR_HIDDEN_TITLE      = 'g2_hidden_title';      // Does hook_view include a hidden version of title for hook_update_index
  const VAR_HOMONYMS_NID      = 'g2_homonyms_nid';      // disambiguation template page for homonyms
  const VAR_HOMONYMS_REDIRECT = 'g2_homonyms_redirect'; // The HTTP 30x code to be used for automatic redirects
  const VAR_HOMONYMS_VID      = 'g2_homonyms_vid';      // disambiguation vocabulary id for homonyms
  const VAR_LATEST_COUNT      = 'g2_latest_count';      // Latest(x) block: value of x
  const VAR_LATEST_TITLE      = 'g2_latest_title';      // Latest(x) block: title
  const VAR_MAIN_NID          = 'g2_main_nid';          // nid of the node used as main page for G2
  const VAR_NO_FREETAGGING    = 'g2_nofreetagging';     // Hide information from freetagging vocabularies to non-G2 admins
  const VAR_PAGE_TITLE        = 'g2_page_title';        // Override for default site title on G2 pages
  const VAR_PATH_MAIN         = 'g2_path_main';         // path for the G2 main page
  const VAR_RANDOM_ENTRY      = 'g2_random_entry';      // Random block: latest pseudo-random entry displayed
  const VAR_RANDOM_STORE      = 'g2_random_store';      // Random block: store the latest random entry
  const VAR_RANDOM_TERMS      = 'g2_random_terms';      // Random block: show terms bound to entry
  const VAR_RANDOM_TITLE      = 'g2_random_title';      // Random block: title
  const VAR_REMOTE_G2         = 'g2_remote_g2';         // Base URL of remote G2 instance
  const VAR_RPC_THROTTLE      = 'g2_rpc_throttle';      // Coefficient limit for XML-RPC operations over block settings
  const VAR_TOP_COUNT         = 'g2_top_count';         // Top(x) block: value of x
  const VAR_TOP_TITLE         = 'g2_top_title';         // Top(x) block: title
  const VAR_WOTD_AUTO_CHANGE  = 'g2_wotd_auto_change';  // WOTD block: automatically change the WOTD once a day
  const VAR_WOTD_BODY_SIZE    = 'g2_wotd_body_size';    // WOTD block: number of body characters to be displayed in the block
  const VAR_WOTD_DATE         = 'g2_wotd_date';         // WOTD block: date for which this WOTD entry is current. Default to time()
  const VAR_WOTD_ENTRY_NID    = 'g2_wotd_entry_nid';    // WOTD block: current entry
  const VAR_WOTD_FEED_AUTHOR  = 'g2_wotd_feed_author';  // WOTD block feed: include the author in the feed entries
  const VAR_WOTD_FEED_DESCR   = 'g2_wotd_feed_descr';   // WOTD block feed: the description for the WOTD RSS feed
  const VAR_WOTD_FEED_LINK    = 'g2_wotd_feed_link';    // WOTD block feed: include a link to the WOTD RSS feed in the block
  const VAR_WOTD_FEED_TITLE   = 'g2_wotd_feed_title';   // WOTD block feed: the title for the WOTD RSS feed
  const VAR_WOTD_TERMS        = 'g2_wotd_terms';        // WOTD block: show terms bound to entry
  const VAR_WOTD_TITLE        = 'g2_wotd_title';        // WOTD block: title
  const VAR_XMLRPC            = 'g2_xmlrpc';            // Is the XML-RPC server enabled ?

/**
 * G2 default values for some of the persistent variables above
 */
  const DEF_ALPHABAR_STRING      = '0123456789abcdefghijklmnopqrstuvwxyz';
  const DEF_ALPHABAR_ROW_LEN     = 13;
  const DEF_ALPHABAR_TITLE       = 'G2 Glossary pages';
  const DEF_GOTO_SINGLE          = TRUE;
  const DEF_HIDDEN_TITLE         = TRUE;
  const DEF_HOMONYMS_NID         = 0;
  const DEF_HOMONYMS_REDIRECT    = '302'; // The HTTP (string) 30x code to be used for automatic redirects
  const DEF_HOMONYMS_VID         = 0;
  const DEF_LATEST_COUNT         = 10;
  const DEF_LATEST_TITLE         = '%d most recently updated G2 glossary entries'; // %d is a sprintf formatter, not a t() placeholder
  const DEF_MAIN_NID             = 0;
  const DEF_NO_FREETAGGING       = TRUE;
  const DEF_PATH_MAIN            = 'g2';
  const DEF_PAGE_TITLE           = 'G2 Glossary on %title';
  const DEF_RANDOM_ENTRY         = '';
  const DEF_RANDOM_STORE         = TRUE; // only larger sites should set it to false
  const DEF_RANDOM_TERMS         = FALSE;
  const DEF_RANDOM_TITLE         = 'Random G2 glossary entry';
  const DEF_REMOTE_G2            = 'http://www.riff.org/g2/entries';
  const DEF_REMOTE_NO            = '<local>';
  const DEF_RPC_THROTTLE         = 10;
  const DEF_TOP_COUNT            = 10;
  const DEF_TOP_TITLE            = '%d most popular G2 glossary entries'; // sprintf, see g2_block('view')
  const DEF_WOTD_AUTO_CHANGE     = TRUE;
  const DEF_WOTD_BODY_SIZE       = 0;
  const DEF_WOTD_ENTRY_NID       = 0;
  const DEF_WOTD_FEED_AUTHOR     = '!author'; // This default will use the actual node author
  const DEF_WOTD_FEED_DESCR      = 'A daily definition from the G2 Glossary at !site';  // see _g2_wotd_feed()
  const DEF_WOTD_FEED_LINK       = TRUE;
  const DEF_WOTD_TERMS           = FALSE;
  const DEF_WOTD_TITLE           = 'Word of the day in the G2 glossary';
  const DEF_XMLRPC               = FALSE;
  }
